require 'spec_helper'

describe 'performing a payout' do
  let(:success_body)  { '<?xml version="1.0" encoding="UTF-8" standalone="yes" ?><PerformPayoutPayment><Description></Description><PaymentID>333</PaymentID><Status>000</Status><PayoneerID>1234</PayoneerID></PerformPayoutPayment>' }
  let(:fail_body)     { '<?xml version="1.0" encoding="UTF-8" standalone="yes" ?><PerformPayoutPayment><Description>Payee does not exist</Description><PaymentID>666</PaymentID><Status>002</Status><PayoneerID>8888</PayoneerID></PerformPayoutPayment>' }
  let(:expected_params) { {
    :p1 => 'frankie',
    :p2 => 'bloggs',
    :p3 => 'p90001',
    :p4 => 'program12345',
    :p5 => '1234',
    :p6 => '44',
    :p7 => '300',
    :p8 => 'Hello Worlds',
    :p9 => Time.now.utc.strftime("%m/%d/%Y %H:%M:%S")
  } }

  before do
    Timecop.freeze

    Payoneer::Configuration.environment = :sandbox
    Payoneer::Configuration.partner_id = 'p90001'
    Payoneer::Configuration.username = 'frankie'
    Payoneer::Configuration.password = 'bloggs'
    Payoneer::Configuration.program_id = 'program12345'

    stub_request(:post, "https://api.sandbox.payoneer.com/payouts/HttpApi/Api.aspx?mname=PerformPayoutPayment").with(:body => expected_params).to_return(:body => response_body)
  end

  context 'when a successful payout is made' do
    let(:response_body) { success_body }

    it 'returns success' do
      response = Payoneer::PerformPayoutPaymentRequest.new.perform_payment 1234, 44, 300, 'Hello Worlds'
      expect(response.success?).to eq(true)
    end
  end

  context 'when a failed payout is made' do
    let(:response_body) { fail_body }

    it 'returns failure' do
      response = Payoneer::PerformPayoutPaymentRequest.new.perform_payment 1234, 44, 300, 'Hello Worlds'
      expect(response.success?).to eq(false)
      expect(response.error_message).to eq("Payee does not exist")
    end
  end
end
